@@ -109,18 +109,21 @@
 #' 
 #' # the coefficients can be accessed with:
 #' coef(lsem)
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
 #' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
-#' # AIC and BIC:
-#' AIC(lsem)
-#' BIC(lsem)
+#' # fit Measures:
+#' fitIndices(lsem)
 #' 
 #' # The best parameters can also be extracted with:
 #' coef(lsem, criterion = "AIC")
-#' coef(lsem, criterion = "BIC")
-#' 
+#' # or
+#' estimates(lsem, criterion = "AIC") 
 #' 
 #' #### Advanced ###
 #' # Switching the optimizer # 
@@ -289,18 +292,21 @@ lasso <- function(lavaanModel,
 #' 
 #' # the coefficients can be accessed with:
 #' coef(lsem)
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
 #' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
-#' # AIC and BIC:
-#' AIC(lsem)
-#' BIC(lsem)
+#' # fit Measures:
+#' fitIndices(lsem)
 #' 
 #' # The best parameters can also be extracted with:
 #' coef(lsem, criterion = "AIC")
-#' coef(lsem, criterion = "BIC")
-#' 
+#' # or
+#' estimates(lsem, criterion = "AIC")
 #' 
 #' #### Advanced ###
 #' # Switching the optimizer #
@@ -703,6 +709,8 @@ elasticNet <- function(lavaanModel,
 #' @param thetas parameters whose absolute value is above this threshold will be penalized with
 #' a constant (theta)
 #' @param modifyModel used to modify the lavaanModel. See ?modifyModel.
+#' @param method which optimizer should be used? Currently implemented are ista
+#' and glmnet. With ista, the control argument can be used to switch to related procedures
 #' @param control used to control the optimizer. This element is generated with 
 #' the controlIsta (see ?controlIsta)
 #' @returns Model of class regularizedSEM
@@ -739,10 +747,22 @@ elasticNet <- function(lavaanModel,
 #' 
 #' # the coefficients can be accessed with:
 #' coef(lsem)
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
 #' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
+#' # fit Measures:
+#' fitIndices(lsem)
+#' 
+#' # The best parameters can also be extracted with:
+#' coef(lsem, criterion = "AIC")
+#' # or
+#' estimates(lsem, criterion = "AIC")
+#' 
 #' # optional: plotting the paths requires installation of plotly
 #' # plot(lsem)
 #' @export
@@ -751,7 +771,8 @@ cappedL1 <- function(lavaanModel,
                      lambdas,
                      thetas,
                      modifyModel = lessSEM::modifyModel(),
-                     control = lessSEM::controlIsta()){
+                     method = "glmnet",
+                     control = lessSEM::controlGlmnet()){
   if(any(thetas <= 0)) stop("Theta must be > 0")
   
   result <- .regularizeSEMInternal(lavaanModel = lavaanModel, 
@@ -760,7 +781,7 @@ cappedL1 <- function(lavaanModel,
                                            tuningParameters = expand.grid(lambda = lambdas, 
                                                                           theta = thetas,
                                                                           alpha = 1), 
-                                           method = "ista", 
+                                           method = method, 
                                            modifyModel = modifyModel, 
                                            control = control
   )
@@ -827,6 +848,8 @@ cappedL1 <- function(lavaanModel,
 #' @param thetas parameters whose absolute value is above this threshold will be penalized with
 #' a constant (theta)
 #' @param modifyModel used to modify the lavaanModel. See ?modifyModel.
+#' @param method which optimizer should be used? Currently implemented are ista
+#' and glmnet. With ista, the control argument can be used to switch to related procedures
 #' @param control used to control the optimizer. This element is generated with 
 #' the controlIsta (see ?controlIsta)
 #' @returns Model of class regularizedSEM
@@ -863,10 +886,22 @@ cappedL1 <- function(lavaanModel,
 #' 
 #' # the coefficients can be accessed with:
 #' coef(lsem)
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
 #' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
+#' # fit Measures:
+#' fitIndices(lsem)
+#' 
+#' # The best parameters can also be extracted with:
+#' coef(lsem, criterion = "AIC")
+#' # or
+#' estimates(lsem, criterion = "AIC")
+#' 
 #' # optional: plotting the paths requires installation of plotly
 #' # plot(lsem)
 #' @export
@@ -875,7 +910,8 @@ lsp <- function(lavaanModel,
                 lambdas,
                 thetas,
                 modifyModel = lessSEM::modifyModel(),
-                control = lessSEM::controlIsta()){
+                method = "glmnet",
+                control = lessSEM::controlGlmnet()){
   
   if(any(thetas <= 0)) stop("Theta must be > 0")
   
@@ -884,7 +920,7 @@ lsp <- function(lavaanModel,
                                            weights = regularized,
                                            tuningParameters = expand.grid(lambda = lambdas, 
                                                                           theta = thetas), 
-                                           method = "ista", 
+                                           method = method, 
                                            modifyModel = modifyModel, 
                                            control = control
   )
@@ -900,7 +936,7 @@ lsp <- function(lavaanModel,
 #' \ifelse{html}{\deqn{p( x_j) = \begin{cases}
 #' \lambda |x_j| - x_j^2/(2\theta) & \text{if } |x_j| \leq \theta\lambda\\
 #' \theta\lambda^2/2 & \text{if } |x_j| > \lambda\theta
-#' \end{cases}} where \eqn{\theta > 0}.}{
+#' \end{cases}} where \eqn{\theta > 1}.}{
 #' Equation Omitted in Pdf Documentation.}
 #' 
 #' Identical to \pkg{regsem}, models are specified using \pkg{lavaan}. Currently,
@@ -910,6 +946,9 @@ lsp <- function(lavaanModel,
 #' \pkg{lessSEM} will then automatically switch to full information maximum likelihood
 #' as well.
 #' 
+#' In our experience, the glmnet optimizer can run in issues with the mcp penalty.
+#' Therefor, we default to using ista.
+#' 
 #' mcp regularization:
 #' 
 #' * Zhang, C.-H. (2010). Nearly unbiased variable selection under minimax concave penalty. 
@@ -953,6 +992,9 @@ lsp <- function(lavaanModel,
 #' @param thetas parameters whose absolute value is above this threshold will be penalized with
 #' a constant (theta)
 #' @param modifyModel used to modify the lavaanModel. See ?modifyModel.
+#' @param method which optimizer should be used? Currently implemented are ista
+#' and glmnet. With ista, the control argument can be used to switch to related procedures
+#' (currently gist).
 #' @param control used to control the optimizer. This element is generated with 
 #' the controlIsta (see ?controlIsta)
 #' @returns Model of class regularizedSEM
@@ -990,9 +1032,22 @@ lsp <- function(lavaanModel,
 #' # the coefficients can be accessed with:
 #' coef(lsem)
 #' 
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
+#' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
+#' # fit Measures:
+#' fitIndices(lsem)
+#' 
+#' # The best parameters can also be extracted with:
+#' coef(lsem, criterion = "AIC")
+#' # or
+#' estimates(lsem, criterion = "AIC")
+#' 
 #' # optional: plotting the paths requires installation of plotly
 #' # plot(lsem)
 #' @export
@@ -1001,15 +1056,19 @@ mcp <- function(lavaanModel,
                 lambdas,
                 thetas,
                 modifyModel = lessSEM::modifyModel(),
+                method = "ista",
                 control = lessSEM::controlIsta()){
   
-  if(any(thetas <= 0)) stop("Theta must be > 0")
+  if(any(thetas <= 0)) 
+    stop("Theta must be > 0")
+  if(any(thetas <= 1) & method == "glmnet") 
+    warning("thetas is typically > 1. Note that glmnet may run into issues with small theta.")
   result <- .regularizeSEMInternal(lavaanModel = lavaanModel, 
                                            penalty = "mcp", 
                                            weights = regularized,
                                            tuningParameters = expand.grid(lambda = lambdas, 
                                                                           theta = thetas), 
-                                           method = "ista", 
+                                           method = method, 
                                            modifyModel = modifyModel, 
                                            control = control
   )
@@ -1084,10 +1143,12 @@ mcp <- function(lavaanModel,
 #' @param thetas parameters whose absolute value is above this threshold will be penalized with
 #' a constant (theta)
 #' @param modifyModel used to modify the lavaanModel. See ?modifyModel.
+#' @param method which optimizer should be used? Currently implemented are ista
+#' and glmnet. With ista, the control argument can be used to switch to related procedures
+#' (currently gist).
 #' @param control used to control the optimizer. This element is generated with 
 #' the controlIsta (see ?controlIsta)
 #' @returns Model of class regularizedSEM
-
 #' @examples 
 #' library(lessSEM)
 #' 
@@ -1122,9 +1183,22 @@ mcp <- function(lavaanModel,
 #' # the coefficients can be accessed with:
 #' coef(lsem)
 #' 
+#' # if you are only interested in the estimates and not the tuning parameters, use
+#' coef(lsem)@estimates
+#' # or
+#' estimates(lsem)
+#' 
 #' # elements of lsem can be accessed with the @ operator:
 #' lsem@parameters[1,]
 #' 
+#' # fit Measures:
+#' fitIndices(lsem)
+#' 
+#' # The best parameters can also be extracted with:
+#' coef(lsem, criterion = "AIC")
+#' # or
+#' estimates(lsem, criterion = "AIC")
+#' 
 #' # optional: plotting the paths requires installation of plotly
 #' # plot(lsem)
 #' @export
@@ -1133,7 +1207,8 @@ scad <- function(lavaanModel,
                  lambdas,
                  thetas,
                  modifyModel = lessSEM::modifyModel(),
-                 control = lessSEM::controlIsta()){
+                 method = "glmnet",
+                 control = lessSEM::controlGlmnet()){
   
   if(any(thetas <= 2)) stop("Theta must be > 2")
   
@@ -1142,7 +1217,7 @@ scad <- function(lavaanModel,
                                            weights = regularized,
                                            tuningParameters = expand.grid(lambda = lambdas, 
                                                                           theta = thetas), 
-                                           method = "ista", 
+                                           method = method, 
                                            modifyModel = modifyModel, 
                                            control = control
   )
